.. _spkg_jsonpointer:

jsonpointer: Identify specific nodes in a JSON document (RFC 6901)
==================================================================

Description
-----------

Identify specific nodes in a JSON document (RFC 6901)

License
-------

Modified BSD License

Upstream Contact
----------------

https://pypi.org/project/jsonpointer/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.4

version_requirements.txt::

    jsonpointer

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install jsonpointer

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i jsonpointer

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-jsonpointer


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
